# Freeze Pop
 Generate MIDI files with tracker-inspired methods.

## Cubes
Describe here

## Freezers
Describe here

## Notes
Describe here

## Phrases
Describe here

## Sections
Describe here

## Tracks
Describe here

## Songs
Describe here
